@@ -69,6 +69,12 @@ describe 'neutron' do
       it_configures 'rabbit with durable queues'
     end
 
+    context 'with rabbitmq non default transient_queues_ttl' do
+      before { params.merge!( :rabbit_transient_queues_ttl => 20 ) }
+      it_configures 'rabbit with non default transient_queues_ttl'
+    end
+
+
     it_configures 'with SSL enabled with kombu'
     it_configures 'with SSL enabled without kombu'
     it_configures 'with SSL disabled'
@@ -81,8 +87,6 @@ describe 'neutron' do
     it_configures 'with log_file specified'
     it_configures 'without service_plugins'
     it_configures 'with service_plugins'
-    it_configures 'without memcache_servers'
-    it_configures 'with memcache_servers'
     it_configures 'with host defined'
     it_configures 'with dns_domain defined'
     it_configures 'with transport_url defined'
@@ -144,8 +148,6 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('DEFAULT/global_physnet_mtu').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dhcp_agent_notification').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/allow_bulk').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/allow_pagination').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/allow_sorting').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/allow_overlapping_ips').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/api_extensions_path').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/control_exchange').with_value('neutron')
@@ -190,6 +192,12 @@ describe 'neutron' do
     end
   end
 
+  shared_examples_for 'rabbit with non default transient_queues_ttl' do
+    it 'in neutron.conf' do
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_transient_queues_ttl').with_value(20)
+    end
+  end
+
   shared_examples_for 'rabbit_ha_queues set to false' do
     it 'in neutron.conf' do
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(false)
@@ -412,23 +420,6 @@ describe 'neutron' do
 
   end
 
-  shared_examples_for 'without memcache_servers' do
-    it { is_expected.to contain_neutron_config('DEFAULT/memcached_servers').with_ensure('absent') }
-  end
-
-  shared_examples_for 'with memcache_servers' do
-    before do
-      params.merge!(
-        :memcache_servers => ['memcache1','memcache2','memcache3']
-      )
-    end
-
-    it do
-      is_expected.to contain_neutron_config('DEFAULT/memcached_servers').with_value('memcache1,memcache2,memcache3')
-    end
-
-  end
-
   shared_examples_for 'with global_physnet_mtu defined' do
     before do
       params.merge!(
